@@ -13,7 +13,7 @@ use Image::Random;
 use Video::Delay::Const;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -102,7 +102,7 @@ sub _symlink {
 		}
 		if (! $has_symlink) {
 			require File::Copy;
-			copy($from, $to);
+			File::Copy::copy($from, $to);
 		}
 	} else {
 		symlink $from, $to;
@@ -263,6 +263,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
